## Overview

This directory contains the source code of the TBB core components.

## Directories

tools_api
  Source code of the interface components provided by the Intel® Parallel Studio tools.
intel64-masm
  Assembly code for the Intel® 64 architecture.
ia32-masm
  Assembly code for IA32 architecture.
ia64-gas
  Assembly code for IA-64 architecture.
ibm_aix51
  Assembly code for AIX 5.1 port.

Up to parent directory

Copyright © 2005-2018 Intel Corporation. All Rights Reserved.

Intel is a registered trademark or trademark of Intel Corporation or its subsidiaries in the United States and other countries.

* Other names and brands may be claimed as the property of others.